## Effective-octo
- This is a simple, educative, open sourde code 
- The package contains 3 modules which are
# Tic-Tac-Toe
# Rock-Paper-Scissor
# Snake
- After importing the module 
- The games can be invoked by calling the main function .main() in them 
- no arguments are required 
- github url https://github.com/2028-design/effective-octo
## License
MIT